@@ -5,7 +5,7 @@ import sys
 import zipfile
 from collections import namedtuple
 from datetime import datetime
-from io import BytesIO
+from io import BytesIO, StringIO
 
 import rebotics_sdk
 
@@ -19,12 +19,26 @@ class ClassificationDatabaseException(Exception):
 
 
 class BaseClassificationDatabasePacker(object):
+    version = 0
+    extension = 'zip'
+
     def __init__(self, source=None, destination=None):
         self.source = source
         self.destination = destination
-        self.meta_data = None
+        self.meta_data = {
+            'packed': datetime.now().strftime('%c'),
+            'sdk_version': rebotics_sdk.__version__,
+            'packer_version': self.version
+        }
         self.images = []
 
+        if self.destination is None:
+            self.destination = BytesIO()
+        elif isinstance(self.destination, str):
+            self.destination = "{}.{}".format(self.destination, self.extension)
+        else:
+            raise ClassificationDatabaseException('destination should be None or path-like')
+
     def read_lines(self, lines):
         return [x for x in lines.split('\n') if x]
 
@@ -58,17 +72,39 @@ class BaseClassificationDatabasePacker(object):
 
 
 class ZipDatabasePacker(BaseClassificationDatabasePacker):
+    """
+    Unified file format for packing classification database into single folder
+    File format is the zip based archive with following :
+
+    labels.txt
+    features.txt
+    meta.json
+    """
     version = 0
     extension = 'zip'
 
-    def pack(self, labels_path, features_path, *args, **kwargs):
-        raise NotImplementedError("Use the classification database packer")
+    def pack(self, labels, features, *args, **kwargs):
+        labels_io = StringIO("\n".join(labels))
+        features_io = StringIO("\n".join(features))
+        self.meta_data['count'] = len(labels)
+
+        with self.zipfile(self.destination, mode='w') as zip_io:
+            zip_io.writestr('labels.txt', labels_io.getvalue())
+            zip_io.writestr('features.txt', features_io.getvalue())
+            zip_io.writestr('meta.json', json.dumps(self.meta_data))
+        return self.destination
 
     def unpack(self):
         if self.source is None:
             raise ClassificationDatabaseException("Can not unpack with empty source file")
 
         with self.zipfile(self.source, mode='r') as zip_io:
+            try:
+                self.meta_data = json.load(zip_io.open('meta.json'))
+            except KeyError:
+                # meta.json is not presented, working in the compatibility mode
+                pass
+
             labels = self.read_lines(zip_io.read('labels.txt').decode('utf-8'))
             features = self.read_lines(zip_io.read('features.txt').decode('utf-8'))
 
@@ -126,25 +162,15 @@ class ClassificationDatabasePacker(BaseClassificationDatabasePacker):
                     labels_count, features_count, files_count
                 ))
 
-        self.meta_data = {
+        self.meta_data.update({
             'count': features_count,
             'images': [str(f[0]) for f in self.images]
-        }
+        })
 
     def pack(self, labels_path, features_path, images_folder):
         self.extract_meta_data(labels_path, features_path, images_folder)
-        if self.destination is None:
-            destination = BytesIO()
-        elif isinstance(self.destination, str):
-            destination = "{}.{}".format(self.destination, self.extension)
-        else:
-            raise ClassificationDatabaseException('destination should be None or path-like')
 
-        self.meta_data['packed'] = datetime.now().strftime('%c')
-        self.meta_data['sdk_version'] = rebotics_sdk.__version__
-        self.meta_data['packer_version'] = self.version
-
-        with self.zipfile(destination, mode='w') as zip_io:
+        with self.zipfile(self.destination, mode='w') as zip_io:
             zip_io.write(labels_path, 'labels.txt')
             zip_io.write(features_path, 'features.txt')
             for name, path in self.images:
@@ -152,7 +178,7 @@ class ClassificationDatabasePacker(BaseClassificationDatabasePacker):
 
             zip_io.writestr('meta.json', json.dumps(self.meta_data))
 
-        return destination
+        return self.destination
 
     def unpack(self):
         """
