@@ -9,7 +9,6 @@ import click
 import humanize
 import requests
 from prettytable import PrettyTable
-from pynotifier import Notification
 
 from rebotics_sdk.cli.common import shell, configure, roles
 from .utils import ReboticsCLIContext, app_dir, pass_rebotics_context, read_saved_role, process_role
@@ -80,10 +79,15 @@ def retailer_versions(ctx, notify, delay):
     if notify:
         if ctx.verbose:
             click.echo('Using notify option', err=True)
-        Notification(
-            title='Subscribed to the notifications',
-            description='You will receive notifications for retailer updates',
-        ).send()
+
+        try:
+            from pynotifier import Notification
+            Notification(
+                title='Subscribed to the notifications',
+                description='You will receive notifications for retailer updates',
+            ).send()
+        except ImportError:
+            raise click.ClickException("You can't use notify function")
 
     provider = ctx.provider
     if ctx.verbose:
