@@ -1,8 +1,8 @@
 import json
 
 import six
-from rebotics_sdk.providers.utils import hash_file, accept_file
 
+from rebotics_sdk.providers.utils import hash_file, accept_file
 from .base import ReboticsBaseProvider, remote_service, PageResult
 
 
@@ -72,6 +72,7 @@ class RetailerProvider(ReboticsBaseProvider):
         store_planogram=None,
         aisle=None, section=None,
         klt_json=None, lens_used=None,
+        **kwargs
     ):
         """
         Create processing action for store using list of files
@@ -83,6 +84,7 @@ class RetailerProvider(ReboticsBaseProvider):
         :param str section:
         :param klt_json:
         :param lens_used:
+        :param kwargs: all other fields that are sent to reference
         :return:
         """
         for f_ in files:
@@ -119,7 +121,11 @@ class RetailerProvider(ReboticsBaseProvider):
 
         if lens_used is not None:
             data['lens_used'] = lens_used
-        return self.session.post(data=data)
+
+        for k, v in kwargs.items():
+            data[k] = v
+
+        return self.session.post(json=data)
 
     @remote_service('/api/v4/processing/upload/')
     def processing_upload(self, store_id, input_file, input_type='image'):
